@@ -1,8 +1,8 @@
-from lcapy import ui
+from lcapy import delta
 from lcapy.discretetime import n
 from matplotlib.pyplot import savefig
 
-x = ui(n) + ui(n - 2)
+x = delta(n) + delta(n - 2)
 x.plot(figsize=(6, 2))
 
 savefig('dt1-plot1.png')
