@@ -60,6 +60,8 @@ from .statespace import *
 from .nodalanalysis import *
 from .loopanalysis import *
 from .laplace import *
+from .nettransform import *
+from .randomnetwork import *
 
 
 def show_version():
