@@ -10,7 +10,7 @@ excludes = ['I', 'C', 'O', 'S', 'N', 'E', 'E1', 'Q', 'beta', 'gamma', 'zeta',
 
 # Aliases for SymPy symbols
 aliases = {'delta': 'DiracDelta', 'step': 'Heaviside', 'u': 'Heaviside',
-           'j': 'I'}
+           'H': 'Heaviside', 'j': 'I'}
 
 import sympy as sym
 str_expr_map = {sym.I: 'j'}
@@ -29,7 +29,7 @@ pretty_expr_map = {sym.I: junicode, sym.Heaviside: 'u'}
 functions = ('heaviside', 'diracdelta', 'conjugate', 'sqrt', 'exp',
              'log', 'log10', 'sin', 'cos', 'tan', 'cot' 'asin',
              'acos', 'atan', 'atan2', 'acot', 'sinh', 'cosh', 'tanh', 'asinh',
-             'acosh', 'atanh', 'gcd', 'abs', 'unitimpulse', 'arg')
+             'acosh', 'atanh', 'gcd', 'abs', 'unitimpulse', 'arg', 'sign')
 
 subscripts = ('in', 'out', 'ref', 'rms', 'load', 'source', 'avg',
               'mean', 'peak', 'pk', 'pk-pk', 'pp', 'min', 'max', 'src', 'bat',
