@@ -19,6 +19,7 @@ from .sym import capitalize_name, tsym, symsymbol, symbol_map
 from .state import state
 from .printing import pprint, pretty, print_str, latex
 from .functions import sqrt, log10, atan2, gcd, exp, Function
+from .utils import as_N_D, as_sum
 import numpy as np
 import sympy as sym
 from sympy.utilities.lambdify import lambdify
@@ -387,6 +388,17 @@ class Expr(ExprPrint, ExprMisc):
         # say for subs.
         return hash(self.expr)
 
+
+    def _to_class(self, cls, expr):
+
+        if isinstance(expr, list):
+            return ExprList(expr)
+        elif isinstance(expr, tuple):
+            return ExprTuple(expr)
+        elif isinstance(expr, dict):
+            return ExprDict(expr)
+        return cls(expr)
+    
 # This will allow sym.sympify to magically extract the sympy expression
 # but it will also bypass our __rmul__, __radd__, etc. methods that get called
 # when sympy punts.  Thus pi * t becomes a Mul rather than tExpr.
@@ -400,9 +412,9 @@ class Expr(ExprPrint, ExprMisc):
         if False:
             print(self.__class__.__name__, attr)
 
-        expr = self.expr            
+        expr1 = self.expr            
         try:
-            a = getattr(expr, attr)
+            a = getattr(expr1, attr)
         except:
             raise
             
@@ -421,7 +433,7 @@ class Expr(ExprPrint, ExprMisc):
             ret = a()                
             if hasattr(self, 'assumptions'):
                 return self.__class__(ret, **self.assumptions)
-            return self.__class__(ret)
+            return self._to_class(self.__class__, ret)
 
         # If it is callable, create a function to pass arguments
         # through and wrap its return value.
@@ -432,14 +444,16 @@ class Expr(ExprPrint, ExprMisc):
             ret = a(*args, **kwargs)
             
             if not isinstance(ret, sym.Expr):
-                # May have tuple, etc.
+                # May have tuple, etc.   These could be wrapped but
+                # it appears that this leads to more grief when working
+                # with SymPy.
                 return ret
             
             # Wrap the return value
             cls = self.__class__
             if hasattr(self, 'assumptions'):
                 return cls(ret, **self.assumptions)
-            return cls(ret)
+            return self._to_class(self.__class__, ret)            
         
         return wrap
 
@@ -1164,16 +1178,15 @@ class Expr(ExprPrint, ExprMisc):
 
         return evaluate_expr(expr, var, arg)
 
-    def has(self, subexpr):
-        """Test whether the sub-expression is contained.  For example,
+    def has(self, *patterns):
+        """Test whether any subexpressions matches any of the patterns.  For example,
          V.has(exp(t)) 
          V.has(t)
 
         """
 
-        if isinstance(subexpr, (Expr, Function)):
-            subexpr = subexpr.expr
-        return self.expr.has(subexpr)
+        tweak_patterns = [pattern.expr if isinstance(pattern, (Expr, Function)) else pattern for pattern in patterns]
+        return self.expr.has(*tweak_patterns)
 
     def has_symbol(self, sym):
         """Test if have symbol contained.  For example,
@@ -1307,6 +1320,22 @@ class Expr(ExprPrint, ExprMisc):
         ret = symsimplify(self.expr)
         return self.__class__(ret, **self.assumptions)
 
+    def simplify_terms(self):
+        """Simplify terms in expression individually."""
+
+        result = 0
+        for term in self.expr.expand().as_ordered_terms():
+            result += symsimplify(term)
+        return self.__class__(result, **self.assumptions)
+
+    def simplify_factors(self):
+        """Simplify factors in expression individually."""
+
+        result = 0
+        for factor in self.expr.factor().as_ordered_factors():
+            result *= symsimplify(factor)
+        return self.__class__(result, **self.assumptions)        
+
     def replace(self, query, value, map=False, simultaneous=True, exact=None):
 
         try:
@@ -1799,34 +1828,9 @@ class Expr(ExprPrint, ExprMisc):
                      -s⋅τ
         N = V₁ - V₂⋅ℯ    
         D =  s⋅(L⋅s + R)"""
-        
-        N = 1
-        D = 1
-        factors = self.expr.as_ordered_factors()
 
-        # I.as_ordered_factors()    
-        #
-        # ⎡1     1         s⋅τ        -s⋅τ⎤
-        # ⎢─, ───────, V₁⋅ℯ    - V₂, ℯ    ⎥
-        # ⎣s  L⋅s + R                     ⎦
-        
-        for factor in factors:
-            a, b = factor.as_numer_denom()
-            N *= a
-            if b.is_polynomial(self.var):
-                D *= b
-            else:
-                N /= b
-                
-        N = N.simplify()
-
-        if monic_denominator:
-            Dpoly = sym.Poly(D, self.var)            
-            LC = Dpoly.LC()
-            D = Dpoly.monic().as_expr()
-            N = (N / LC).simplify()
-                
-        return self.__class__(N, **self.assumptions), self.__class__(D, **self.assumptions)                
+        N, D = as_N_D(self.expr, self.var, monic_denominator)
+        return self.__class__(N, **self.assumptions), self.__class__(D, **self.assumptions)
 
     def as_sum(self):
         """Responses due to a sum of delayed transient responses
@@ -1854,14 +1858,8 @@ class Expr(ExprPrint, ExprMisc):
         D is a polynomial.  Then N can be split.
         """
 
-        N, D = self.as_N_D()
-        N = N.simplify()
-
-        result = 0
-        for term in N.expand().as_ordered_terms ():
-            result += term / D
-        return result
-               
+        result = as_sum(self.expr, self.var)
+        return self.__class__(result, **self.assumptions)
     
 def expr(arg, **assumptions):
     """Create Lcapy expression from arg.
@@ -1879,6 +1877,9 @@ def expr(arg, **assumptions):
 
     from .sym import tsym, fsym, ssym, omegasym
 
+    if arg is None:
+        return arg
+    
     if isinstance(arg, Expr) and assumptions == {}:
         return arg
     
