@@ -34,6 +34,7 @@ E: Ename Np Nm Ncp Ncm [Value]; Voltage controlled voltage source
 VCVS: VCVSname Np Nm Ncp Ncm [Value]; Voltage controlled voltage source
 Eopamp: Ename Np Nm opamp Ncp Ncm [Value]; Opamp
 Efdopamp: Ename Np Nm fdopamp Ncp Ncm [Value]; Fully differential opamp
+Eamp: Ename Np Nm amp Ncp Ncm [Value]; Amplifier
 F: Fname Np Nm Vcontrol [Value]; Current controlled current source (note the control current is specified through a voltage source)
 CCCS: CCCSname Np Nm Vcontrol [Value]; Current controlled current source (note the control current is specified through a voltage source)
 FB: FBname Np Nm; Ferrite bead
@@ -53,11 +54,14 @@ Inoise: Iname Np Nm noise [Value] [NID]; Noise current source
 J: Jname Nd Ng Ns [Value]; N channel JFET
 Jnjf: Jname Nd Ng Ns njf [Value]; N channel JFET
 Jpjf: Jname Nd Ng Ns pjf [Value]; P channel JFET
+k: kname Np Nm [Value] [IC]; Spring
 K: Kname Lname1 Lname2 [Value]; Mutual inductance (L1 on left, L2 on right)
 L: Lname Np Nm [Value] [IC]; Inductance
+m: mname Np Nm [Value] [IC]; Mass
 M: Mname Nd Ng Ns [Value]; N channel MOSFET
 Mnmos: Mname Nd Ng Ns nmos [Value]; N channel MOSFET
 Mpmos: Mname Nd Ng Ns pmos [Value]; P channel MOSFET
+MISC: MISCname Np Nm; Miscellaneous circuitikz bipole
 MT: MTname Np Nm; Motor
 MX: MXname P P P; Mixer
 O: Oname Np Np; Open circuit
@@ -65,6 +69,7 @@ P: Pname Np Np; Port
 Q: Qname Nc Nb Ne [Value]; NPN transistor
 Qnpn: Qname Nc Nb Ne npn [Value]; NPN transistor
 Qpnp: Qname Nc Nb Ne pnp [Value]; PNP transistor 
+r: rname Np Nm [Value]; Damper
 R: Rname Np Nm [Value]; Resistor
 RV: RVname Np Nm No [Value] [Value]; Potentiometer
 Sbox: Sname box; Box
@@ -87,9 +92,13 @@ TFtapcore: TFname Np Nm Ncp Ncm tapcore Nt Nt [Value]; Tapped transformer with c
 TL: TLname Np Nm Ncp Ncm [Value]; Transmission line
 TP: TPname Np Nm Ncp Ncm [Value]; Two port
 TR: TRname Pi Po [Value]; Transfer function
-Ubuffer: Uname buffer; Buffer with power supplies
-Uinverter: Uname inverter; Inverter with power supplies
+Ubuffer: Uname buffer; Buffer
+Uinverter: Uname inverter; Inverter
 Udiffamp: Uname diffamp; Differential amplifier
+Uopamp: Uname opamp; Opamp
+Uinamp: Uname inamp; Instrumentation amplifier
+Uisoamp: Uname isoamp; Isolated amplifier
+Ufdopamp: Uname fdopamp; Fully differential opamp
 Uregulator: Uname regulator; Voltage regulator
 Uadc: Uname adc; ADC
 Udac: Uname dac; DAC
@@ -108,6 +117,7 @@ Uchip4444: Uname chip4444; Chip
 Uchip8181: Uname chip8181; Chip
 Uchip8888: Uname chip8888; Chip
 Umux21: Uname mux21; 2-1 multiplexer
+Umux41: Uname mux41; 4-1 multiplexer
 Umux42: Uname mux42; 4-2 multiplexer
 Udff: Uname dff; D flip/flop
 Ujkff: Uname jkff; D flip/flop
@@ -151,7 +161,10 @@ spdt: keyword;
 tap: keyword;
 tapcore: keyword;
 opamp: keyword;
+inamp: keyword;
+isoamp: keyword;
 fdopamp: keyword;
+amp: keyword;
 regulator: keyword;
 buffer: keyword;
 pbuffer: keyword;
@@ -177,6 +190,7 @@ chip4444: keyword;
 chip8181: keyword;
 chip8888: keyword;
 mux21: keyword;
+mux41: keyword;
 mux42: keyword;
 pp: keyword;
 pm: keyword;
