@@ -17,13 +17,13 @@ undefined functions such as v(t) to V(s).
 
 These functions are for internal use by Lcapy.  
 
-Copyright 2016--2019 Michael Hayes, UCECE
+Copyright 2016--2020 Michael Hayes, UCECE
 
 """
 
 from .ratfun import Ratfun
 from .sym import sympify, simplify, AppliedUndef
-from .utils import factor_const, scale_shift
+from .utils import factor_const, scale_shift, as_sum_terms
 import sympy as sym
 
 __all__ = ('LT', 'ILT')
@@ -89,21 +89,21 @@ def laplace_integral(expr, t, s):
 
     const, expr = factor_const(expr, t)
 
-    if len(expr.args) != 1:
+    if len(expr.args) != 2:
         raise ValueError('Cannot compute Laplace transform of %s' % expr)
 
-    expr = expr.args[0]
+    integrand = expr.args[0]
     
     if not isinstance(expr, sym.Integral):
         raise ValueError('Cannot compute Laplace transform of %s' % expr)
 
     # Look for convolution integral
-    
+    # TODO, handle convolution with causal functions.
     var = expr.args[1][0]
     if (expr.args[1][1] != -sym.oo) or (expr.args[1][2] != sym.oo):
         raise ValueError('Need indefinite limits for %s' % expr)
     
-    const2, expr = factor_const(expr.args[0], t)
+    const2, expr = factor_const(integrand, var)
     if ((len(expr.args) != 2)
         or (not isinstance(expr.args[0], AppliedUndef))
         or (not isinstance(expr.args[1], AppliedUndef))):
@@ -160,17 +160,19 @@ def laplace_term(expr, t, s):
         if expr.has(sym.Derivative):
             return laplace_derivative_undef(expr, t, s) * const    
 
-        rest = sym.S.One
-        expr = expr.cancel()
-        for factor in expr.as_ordered_factors():
-            if isinstance(factor, AppliedUndef):
-                result = laplace_func(factor, t, s)
-            else:
-                if factor.has(t):
-                    raise ValueError('TODO: need derivative of undefined'
-                                     ' function for %s' % factor)
-                rest *= factor
-        return result * rest * const
+        factors = expr.as_ordered_factors()
+        if len(factors) == 1:
+            return const * laplace_func(factors[0], t, s)
+        elif len(factors) > 2:
+            raise ValueError('TODO: cannot handle product %s' % expr)
+
+        foo = factors[1]
+        if foo.is_Function and foo.func == sym.exp and foo.args[0].has(t):
+            scale, shift = scale_shift(foo.args[0], t)
+            if shift == 0: 
+                result = laplace_func(factors[0], t, s)
+                return const * result.subs(s, s - scale)
+        raise ValueError('TODO: cannot handle product %s' % expr)
 
     if expr.has(sym.Heaviside(t)):
         return laplace_0(expr.replace(sym.Heaviside(t), 1), t, s) * const
@@ -184,7 +186,7 @@ def laplace_term(expr, t, s):
     return laplace_0(expr, t, s) * const
 
 
-def laplace_transform(expr, t, s):
+def laplace_transform(expr, t, s, evaluate=True):
     """Compute unilateral Laplace transform of expr with lower limit 0-.
 
     Undefined functions such as v(t) are converted to V(s)."""
@@ -193,6 +195,12 @@ def laplace_transform(expr, t, s):
         return sym.Eq(laplace_transform(expr.args[0], t, s),
                       laplace_transform(expr.args[1], t, s))
 
+    if not evaluate:
+        t0 = sympify('t0')
+        result = sym.Limit(sym.Integral(expr * sym.exp(-s * t), (t, t0, sym.oo)),
+                           t0, 0, dir='-')
+        return result
+    
     const, expr = factor_const(expr, t)    
     
     key = (expr, t, s)
@@ -365,11 +373,11 @@ def inverse_laplace_ratfun(expr, s, t, **assumptions):
     return cresult, uresult
 
 
-def dummyvar(intnum=0):
+def dummyvar(intnum=0, var='tau'):
     if intnum == 0:
-        return sympify('tau', real=True)
+        return sympify(var, real=True)
     else:
-        return sympify('tau_%d' % intnum, real=True)    
+        return sympify('%s_%d' % (var, intnum), real=True)    
 
 
 def inverse_laplace_product(expr, s, t, **assumptions):
@@ -427,13 +435,13 @@ def inverse_laplace_product(expr, s, t, **assumptions):
                 continue                
             elif factors[0].is_Pow and factors[0].args[0] == s and factors[0].args[1] == -1:
                 # Handle integration  1 / s * V(s)
-                tau = dummyvar(intnum)
+                tau = dummyvar(intnum, 'tau')
                 intnum += 1
                 result = laplace_func(factors[1], s, tau, True)
                 result = sym.Integral(result, (tau, t1, t))
                 continue                
         # Convert product to convolution
-        tau = dummyvar(intnum)
+        tau = dummyvar(intnum, 'tau')
         intnum += 1
         cresult, uresult = inverse_laplace_term1(factors[m + 1], s, t)
         expr2 = cresult + uresult
@@ -549,20 +557,6 @@ def inverse_laplace_term(expr, s, t, **assumptions):
     return cresult, uresult
 
 
-def inverse_laplace_by_terms(expr, s, t, **assumptions):
-
-    terms = expr.as_ordered_terms()
-
-    cresult = sym.S.Zero
-    uresult = sym.S.Zero    
-
-    for term in terms:
-        const, part1, part2 = inverse_laplace_transform1(term, s, t, **assumptions)
-        cresult += const * part1
-        uresult += const * part2        
-    return cresult, uresult
-
-
 def inverse_laplace_make(t, const, cresult, uresult, **assumptions):
 
     result = const * (cresult + uresult)
@@ -588,8 +582,15 @@ def inverse_laplace_make(t, const, cresult, uresult, **assumptions):
     return result
 
 
-def inverse_laplace_transform1(expr, s, t, **assumptions):
+def inverse_laplace_transform1(expr, s, t, verbatim=False, cache_lookup=True,
+                               **assumptions):
+    """If verbatim is True, do not rewrite expression to assist
+    inverse Laplace transform evaluation.
 
+    If cache_lookup is True, try looking for previously cached result.
+
+    """
+    
     const, expr = factor_const(expr, s)
     
     key = (expr, s, t,
@@ -600,16 +601,23 @@ def inverse_laplace_transform1(expr, s, t, **assumptions):
     if key in inverse_laplace_cache:
         cresult, uresult = inverse_laplace_cache[key]        
         return const, cresult, uresult
-    
-    if expr.is_Add:
-        cresult, uresult = inverse_laplace_by_terms(expr, s, t, **assumptions)
+
+    if verbatim:
+        terms = expr.as_ordered_terms()
     else:
-        try:
-            cresult, uresult = inverse_laplace_term(expr, s, t, **assumptions)
-        except:
-            expr = sym.expand(expr)
-            cresult, uresult = inverse_laplace_by_terms(expr, s, t,
-                                                        **assumptions)
+        # This will break how the user constructs the expression but
+        # it is more likely to produce a tidy result.
+        terms = as_sum_terms(expr, s)
+    if len(terms) == 1:
+        cresult, uresult = inverse_laplace_term(terms[0], s, t, **assumptions)
+    else:
+        cresult = sym.S.Zero
+        uresult = sym.S.Zero    
+
+        for term in terms:
+            const1, part1, part2 = inverse_laplace_transform1(term, s, t, **assumptions)
+            cresult += const1 * part1
+            uresult += const1 * part2
 
     # cresult is known to be causal, uresult is unsure            
     inverse_laplace_cache[key] = cresult, uresult
