@@ -1,7 +1,7 @@
 """
 This module implements a wrapper for the SymPy Matrix class.
 
-Copyright 2019 Michael Hayes, UCECE
+Copyright 2019--2020 Michael Hayes, UCECE
 """
 
 import sympy as sym
@@ -17,7 +17,7 @@ def msympify(expr):
     if isinstance(expr, Expr):
         # Bye bye lcapy type information...
         return expr.expr
-    return expr
+    return sym.sympify(expr)
         
         
 class Matrix(sym.Matrix):
