@@ -16,6 +16,7 @@ from .sym import capitalize_name, omegasym
 from .grammar import delimiters
 from .immitance import ImmitanceMixin
 from .current import Current
+from .opts import Opts
 import lcapy
 import inspect
 import sys
@@ -63,7 +64,7 @@ class Cpt(ImmitanceMixin):
                     node = node[len(self.namespace):]
                 self.relnodes.append(node)
 
-        self.string = string
+        self._string = string
         #self.net = string.split(';')[0]
         # This is the initial opts_string from which the opts attribute
         # is derived.
@@ -72,7 +73,7 @@ class Cpt(ImmitanceMixin):
         self.explicit_args = args        
         self.classname = self.__class__.__name__
         self.keyword = keyword
-        self.opts = {}
+        self.opts = Opts(self.opts_string)
 
         # No defined cpt
         if self.type in ('XX', ):
@@ -112,7 +113,8 @@ class Cpt(ImmitanceMixin):
         return self.__str__()
 
     def __str__(self):
-        return self.string
+        # TODO, use self._netmake() but fix for XX
+        return self._string        
 
     def _stamp(self, cct):
         raise NotImplementedError('stamp method not implemented for %s' % self)
@@ -225,6 +227,9 @@ class Cpt(ImmitanceMixin):
         parts = [name]
         parts.extend(nodes)
         parts.extend(fmtargs)
+
+        # Insert keyword...
+        
         
         net = ' '.join(parts)
         opts_str = str(opts).strip()
@@ -241,10 +246,12 @@ class Cpt(ImmitanceMixin):
         return self._netmake1(self.namespace + newtype, nodes, args=(),
                               opts=opts)
         
-    def _netmake_variant(self, newtype, nodes=None, args=None, opts=None):
+    def _netmake_variant(self, newtype, nodes=None, args=None, opts=None,
+                         suffix=''):
         """This is used for changing cpt name from C1 to ZC1"""
-        return self._netmake1(self.namespace + newtype + self.relname,
-                              nodes, args, opts)
+
+        name = self.namespace + newtype + self.relname + suffix
+        return self._netmake1(name, nodes, args, opts)
     
     def _select(self, kind=None):
         """Select domain kind for component."""
@@ -258,9 +265,13 @@ class Cpt(ImmitanceMixin):
 
         raise ValueError('Component not a source: %s' % self)        
 
+    def _r_model(self):
+        """Return resistive model of component."""
+        return self._copy()
+
     def _s_model(self, var):
         """Return s-domain model of component."""
-        return self._copy()
+        return self._copy()    
 
     def _ss_model(self):
         """Return state-space model of component."""
@@ -342,6 +353,18 @@ class Cpt(ImmitanceMixin):
         else:
             raise ValueError('%s is not a source' % self)        
 
+    @property
+    def is_voltage_source(self):
+        """Return True if component is a voltage source (dependent or
+        independent)"""
+        return self.cpt.voltage_source
+
+    @property
+    def is_current_source(self):
+        """Return True if component is a current source (dependent or
+        independent)"""
+        return self.cpt.current_source    
+        
     @property
     def zeroic(self):
         """Return True if initial conditions are zero (or unspecified)."""
@@ -576,6 +599,9 @@ class XX(Dummy):
         """Rename the nodes using dictionary node_map."""
 
         return self._copy()
+
+    def __str__(self):        
+        return self._string
     
     
 class IndependentSource(Cpt):
@@ -604,10 +630,33 @@ class DependentSource(Dummy):
     
 class RLC(Cpt):
 
+    def _r_model(self):
+
+        dummy_node = self.dummy_node()
+        opts = self.opts.copy()        
+        # Strip voltage and current labels.  FIXME
+        opts = opts.strip_all_labels()
+
+        # Use Thevenin model.  This will require the current through
+        # the voltage source to be explicitly computed.
+        
+        Req = 'R_%seq' % self.type
+        Veq = 'V_%seq' % self.type        
+        
+        rnet = self._netmake_variant('R', suffix='eq',
+                                     nodes=(self.relnodes[0], dummy_node),
+                                     args=Req, opts=opts)
+
+        vnet = self._netmake_variant('V', suffix='eq',
+                                     nodes=(dummy_node, self.relnodes[1]),
+                                     args=Veq, opts=opts)
+
+        return rnet + '\n' + vnet
+
     def _s_model(self, var):
 
         if self.Voc == 0:
-            self._netmake_variant('Z', args=self.Z(var))
+            return self._netmake_variant('Z', args=self.Z(var))
 
         dummy_node = self.dummy_node()
 
@@ -947,8 +996,14 @@ class K(Dummy):
 
         ZL1 = cct.elements[L1].Z.expr
         ZL2 = cct.elements[L2].Z.expr
-        ZM = K.expr * sym.sqrt(ZL1 * ZL2)
 
+        if cct.kind in ('s', 'ivp', 'laplace'):
+            # FIXME, generalise for other domains...
+            # The Impedance class really needs fixing.
+            ZM = K.expr * sym.sqrt(ZL1 * ZL2 / s**2) * s
+        else:
+            ZM = K.expr * sym.sqrt(ZL1 * ZL2)
+            
         m1 = cct._branch_index(L1)
         m2 = cct._branch_index(L2)
 
@@ -1038,7 +1093,9 @@ class P(O):
 
 
 class R(RC):
-    pass
+
+    def _r_model(self):    
+        return self._copy()
 
 
 class RV(RC):
