@@ -14,7 +14,7 @@ from .sexpr import Hs, Zs, Ys
 from .symbols import j, s, omega
 from .voltage import Voltage, Vname
 from .current import Current, Iname
-from .schematic import Schematic, Opts
+from .schematic import Schematic
 from .mna import MNAMixin, Nodedict, Branchdict
 from .statespace import StateSpace
 from .netfile import NetfileMixin
@@ -112,6 +112,7 @@ class NetlistNamespace(object):
         self._netlist = netlist
         # The children namespaces
         self.namespaces = {}
+        self.allow_anon = False
 
     def __getitem__(self, name):
         """Return element or node by name."""
@@ -169,7 +170,7 @@ class NetlistNamespace(object):
         if hasattr(self, '_sch'):
             return self._sch
 
-        sch = Schematic()
+        sch = Schematic(allow_anon=self.allow_anon)
 
         netlist = self._netlist.netlist()
         for net in netlist.split('\n'):
@@ -221,7 +222,7 @@ class NetlistNamespace(object):
 
 class NetlistMixin(object):
 
-    def __init__(self, filename=None, context=None):
+    def __init__(self, filename=None, context=None, allow_anon=False):
 
         self._elements = OrderedDict()
         self.namespaces = {}
@@ -230,7 +231,8 @@ class NetlistMixin(object):
             context = state.new_context()
         
         self.context = context
-        self._init_parser(mnacpts)
+        self.allow_anon = allow_anon
+        self._init_parser(mnacpts, allow_anon=allow_anon)
 
         if filename is not None:
             self.netfile_add(filename)
@@ -314,9 +316,6 @@ class NetlistMixin(object):
 
     def _cpt_add(self, cpt):
 
-        opts = Opts(cpt.opts_string)
-        cpt.opts = opts
-
         if cpt.name in self._elements:
             print('Overriding component %s' % cpt.name)
             # Need to search lists and update component.
@@ -443,8 +442,45 @@ class NetlistMixin(object):
 
         self._node_map = node_map
         return node_map
+
+    def annotate_current(self, cpts, var=None, flow=False, pos=''):
+        """Annotate specified list of component names `cpts` with current (or
+        flow).  `pos` specifies where to position the labels."""
+
+        new = self._new()        
+        for cpt in self._elements.values():
+            net = cpt._copy()
+            if cpt.name in cpts:
+                I = cpt.I
+                if var is not None:
+                    I = I(var)
+
+                net += ', ' if ';' in net else '; '
+                if flow:
+                    net += ', f%s=$%s$' % (pos, I.latex())
+                else:
+                    net += ', i%s=$%s$' % (pos, I.latex())
+            new.add(net)
+        return new
+
+    def annotate_voltage(self, cpts, var=None, pos=''):
+        """Annotate specified list of component names `cpts` with voltage.
+        `pos` specifies where to position the labels."""
+
+        new = self._new()                
+        for cpt in self._elements.values():
+            net = cpt._copy()
+            if cpt.name in cpts:
+                V = cpt.V
+                if var is not None:
+                    V = V(var)
+                net += ', ' if ';' in net else '; '                    
+                net += 'v%s=$%s$' % (pos, V.latex())
+            new.add(net)
+        return new                
     
     def augment_node_map(self, node_map={}):
+
         """Create a mapping dict for all nodes."""
 
         # It would be desirable to renumber the nodes say from left to
@@ -542,6 +578,17 @@ class NetlistMixin(object):
                 self._branch_list.append(elt.name)                
         return self._branch_list
 
+    def _check_nodes(self, *nodes):
+
+        str_nodes = []
+        for node in nodes:
+            if isinstance(node, int):
+                node = '%s' % node
+            if node not in self.nodes:
+                raise ValueError('Unknown node %s' % node)
+            str_nodes.append(node)
+        return str_nodes
+    
     def _parse_node_args(self, Np, Nm=None):
         
         if Nm is None:
@@ -568,6 +615,7 @@ class NetlistMixin(object):
         Nm."""
 
         Np, Nm = self._parse_node_args(Np, Nm)
+        Np, Nm = self._check_nodes(Np, Nm)
         
         new = self.copy()
         if new.is_causal:
@@ -605,6 +653,7 @@ class NetlistMixin(object):
         from .oneport import V, Z
 
         Np, Nm = self._parse_node_args(Np, Nm)
+        Np, Nm = self._check_nodes(Np, Nm)        
         Voc = self.Voc(Np, Nm)
         Zoc = self.impedance(Np, Nm)
 
@@ -621,6 +670,7 @@ class NetlistMixin(object):
         from .oneport import I, Y
 
         Np, Nm = self._parse_node_args(Np, Nm)
+        Np, Nm = self._check_nodes(Np, Nm)                        
         Isc = self.Isc(Np, Nm)
         Ysc = self.admittance(Np, Nm)
 
@@ -629,6 +679,19 @@ class NetlistMixin(object):
         # netlist.        
         return I(Isc.time()) | Y(Ysc)
 
+    def match(self, pattern):
+        """Return list of components names matching regular 
+        expression pattern."""
+
+        from re import match
+
+        elts = []
+        for cpt in self._elements.values():
+            if match(pattern, cpt.name):
+                elts.append(cpt.name)
+        return elts
+
+    
     def admittance(self, Np, Nm=None):
         """Return driving-point admittance between nodes
         Np and Nm with independent sources killed and initial
@@ -637,6 +700,7 @@ class NetlistMixin(object):
         s."""        
 
         Np, Nm = self._parse_node_args(Np, Nm)
+        Np, Nm = self._check_nodes(Np, Nm)
         
         new = self.kill()
         if '0' not in new.nodes:
@@ -658,6 +722,7 @@ class NetlistMixin(object):
         s."""
 
         Np, Nm = self._parse_node_args(Np, Nm)
+        Np, Nm = self._check_nodes(Np, Nm)        
         
         new = self.kill()
         if '0' not in new.nodes:
@@ -704,9 +769,11 @@ class NetlistMixin(object):
         are ignored.  Since the result is causal, the frequency response
         can be found by substituting j * omega for s."""
 
+        N1p, N1m, N2p, N2m = self._check_nodes(N1p, N1m, N2p, N2m)
+        
         new = self.kill()
         if '0' not in new.nodes:
-            new.add('W %s 0' % Nm)
+            new.add('W %s 0' % N1m)
         
         new._add('V1_ %s %s {DiracDelta(t)}' % (N1p, N1m))
 
@@ -725,39 +792,95 @@ class NetlistMixin(object):
 
         from .twoport import AMatrix
 
-        if self.Voc(N1p, N1m) != 0 or self.Voc(N2p, N2m) != 0:
-            raise ValueError('Network contains independent sources')
+        N1p, N1m, N2p, N2m = self._check_nodes(N1p, N1m, N2p, N2m)        
+        net = self.kill()        
+        if '0' not in net.nodes:
+            net.add('W %s 0' % N1m)                           
 
         try:
-            self.add('V1_ %s %s {DiracDelta(t)}' % (N1p, N1m))
+            net.add('V1_ %s %s {DiracDelta(t)}' % (N1p, N1m))
 
             # A11 = V1 / V2 with I2 = 0
             # Apply V1 and measure V2 with port 2 open-circuit
-            A11 = Hs(self.V1_.V.laplace() / self.Voc(N2p, N2m).laplace())
+            A11 = Hs(net.V1_.V(s) / net.Voc(N2p, N2m)(s))
 
             # A12 = V1 / I2 with V2 = 0
             # Apply V1 and measure I2 with port 2 short-circuit
-            A12 = Zs(self.V1_.V.laplace() / self.Isc(N2p, N2m).laplace())
+            A12 = Zs(net.V1_.V(s) / net.Isc(N2p, N2m)(s))
 
-            self.remove('V1_')
+            net.remove('V1_')
 
-            self.add('I1_ %s %s {DiracDelta(t)}' % (N1p, N1m))
+            net.add('I1_ %s %s {DiracDelta(t)}' % (N1p, N1m))
 
             # A21 = I1 / V2 with I2 = 0
             # Apply I1 and measure I2 with port 2 open-circuit
-            A21 = Ys(-self.I1_.I.laplace() / self.Voc(N2p, N2m).laplace())
+            A21 = Ys(-net.I1_.I(s) / net.Voc(N2p, N2m)(s))
 
             # A22 = I1 / I2 with V2 = 0
             # Apply I1 and measure I2 with port 2 short-circuit
-            A22 = Hs(-self.I1_.I.laplace() / self.Isc(N2p, N2m).laplace())
+            A22 = Hs(-net.I1_.I(s) / net.Isc(N2p, N2m)(s))
 
-            self.remove('I1_')
-            A = AMatrix(A11, A12, A21, A22)
+            net.remove('I1_')
+            A = AMatrix(((A11, A12), (A21, A22)))
             return A
 
         except ValueError:
             raise ValueError('Cannot create A matrix')
 
+
+    def Zmatrix(self, N1p, N1m, N2p, N2m):
+        """Create Z matrix from network, where:
+        I1 is the current flowing into N1p and out of N1m
+        I2 is the current flowing into N2p and out of N2m
+        V1 is V[N1p] - V[N1m]
+        V2 is V[N2p] - V[N2m]
+        """
+
+        from .twoport import ZMatrix
+
+        N1p, N1m, N2p, N2m = self._check_nodes(N1p, N1m, N2p, N2m)        
+        net = self.kill()
+        if '0' not in net.nodes:
+            net.add('W %s 0' % N1m)
+
+        try:
+            net.add('I1_ %s %s {DiracDelta(t)}' % (N1p, N1m))
+
+            # Z11 = V1 / I1 with I2 = 0
+            # Apply I1 and measure V1 with port 2 open-circuit
+            Z11 = Zs(net.Voc(N1p, N1m)(s) / net.I1_.I(s))
+
+            # Z21 = V2 / I1 with I2 = 0
+            # Apply I1 and measure V2 with port 2 open-circuit
+            Z21 = Zs(net.Voc(N2p, N2m)(s) / net.I1_.I(s))          
+
+            net.remove('I1_')
+
+            net.add('I2_ %s %s {DiracDelta(t)}' % (N2p, N2m))
+
+            # Z12 = V1 / I2 with I1 = 0
+            # Apply I2 and measure V1 with port 1 open-circuit
+            Z12 = Zs(net.Voc(N1p, N1m)(s) / net.I2_.I(s))
+
+            # Z22 = V2 / I2 with I1 = 0
+            # Apply I2 and measure V2 with port 1 open-circuit
+            Z22 = Zs(net.Voc(N2p, N2m)(s) / net.I2_.I(s))          
+
+            net.remove('I2_')            
+
+            Z = ZMatrix(((Z11, Z12), (Z21, Z22)))
+            return Z
+
+        except ValueError:
+            raise ValueError('Cannot create Z matrix')        
+
+    def save(self, filename):
+        """Save netlist to file."""
+
+        f = open(filename, 'w')
+        f.writelines(str(self))
+        f.close()
+        
     def select(self, kind):
         """Return new netlist with transform domain kind selected for
         specified sources in sourcenames. 
@@ -832,6 +955,22 @@ class NetlistMixin(object):
 
         return self._kill(sources)
 
+    def kill_zero(self):
+        """Return a new circuit with the independent zero voltage sources and
+        zero current sources killed."""
+
+        new = self._new()
+
+        for cpt in self._elements.values():
+            if (cpt.independent_source and 
+                (cpt.is_voltage_source and cpt.Voc == 0) or
+                (cpt.is_current_source and cpt.Isc == 0)):
+                net = cpt._kill()
+            else:
+                net = cpt._copy()
+            new._add(net)
+        return new            
+
     def _noisy(self, resistornames):
 
         new = self._new()
@@ -872,22 +1011,44 @@ class NetlistMixin(object):
 
         return self._noisy(resistors)
 
-    def twoport(self, N1p, N1m, N2p, N2m):
-        """Create twoport model from network, where:
+    def twoport(self, N1p, N1m, N2p, N2m, model='B'):
+        """Create s-domain twoport model from network, where:
         I1 is the current flowing into N1p and out of N1m
         I2 is the current flowing into N2p and out of N2m
         V1 is V[N1p] - V[N1m]
         V2 is V[N2p] - V[N2m]
         """
 
-        from .twoport import TwoPortBModel
+        from .twoport import TwoPortBModel, TwoPortHModel, TwoPortYModel, TwoPortZModel
 
-        V2b = self.Voc(N2p, N2m)
-        I2b = self.Isc(N2p, N2m)
+        # TODO, generalise for not just s-domain.
 
-        A = self.kill().Amatrix(N1p, N1m, N2p, N2m)
+        net = self.copy()
+        if '0' not in net.nodes:
+            net.add('W %s 0' % N1m)        
 
-        return TwoPortBModel(A.B, V2b, I2b)
+        if model == 'B':
+            V2b = net.Voc(N2p, N2m)(s)
+            I2b = net.Isc(N2p, N2m)(s)
+            A = net.Amatrix(N1p, N1m, N2p, N2m)
+            return TwoPortBModel(A.B, V2b, I2b)
+        elif model == 'Z':
+            V1 = net.Voc(N1p, N1m)(s)
+            V2 = net.Voc(N2p, N2m)(s)
+            Z = net.Zmatrix(N1p, N1m, N2p, N2m)            
+            return TwoPortZModel(Z, V1, V2)
+        elif model == 'Z':
+            I1 = net.Isc(N1p, N1m)(s)
+            I2 = net.Isc(N2p, N2m)(s)
+            Z = net.Zmatrix(N1p, N1m, N2p, N2m)            
+            return TwoPortYModel(Z.Y, I1, I2)        
+        elif model == 'H':
+            V1 = net.Voc(N1p, N1m)(s)
+            I2 = net.Isc(N2p, N2m)(s)
+            Z = net.Zmatrix(N1p, N1m, N2p, N2m)            
+            return TwoPortHModel(Z.H, V1, I2)
+        else:
+            raise ValueError('Model %s unknown, must be B, H, Y, or Z' % model)
 
     @property
     def sch(self):
@@ -896,7 +1057,7 @@ class NetlistMixin(object):
         if hasattr(self, '_sch'):
             return self._sch
 
-        sch = Schematic()
+        sch = Schematic(allow_anon=self.allow_anon)
 
         netlist = self.netlist()
         for net in netlist.split('\n'):
@@ -954,6 +1115,17 @@ class NetlistMixin(object):
             new._add(net)
         return new        
 
+    def r_model(self):
+        """"Create resistive equivalent model using companion circuits.
+        This is experimental!"""
+
+        new = self._new()
+
+        for cpt in self._elements.values():
+            net = cpt._r_model()
+            new._add(net)
+        return new
+    
     def s_model(self, var=s):
         """"Create s-domain model."""
 
@@ -965,7 +1137,7 @@ class NetlistMixin(object):
         return new
 
     def ss_model(self):
-        """"Create preliminary state-space model by replacing inductors
+        """"Create state-space model by replacing inductors
         with current sources and capacitors with voltage sources."""
 
         new = self._new()
@@ -973,7 +1145,13 @@ class NetlistMixin(object):
         for cpt in self._elements.values():
             net = cpt._ss_model()
             new._add(net)
-        return new            
+        return new
+
+    def state_space_model(self):
+        """"Create state-space model by replacing inductors
+        with current sources and capacitors with voltage sources."""
+        
+        return self.ss_model()
 
     def ac_model(self, var=omega):
         """"Create AC model for specified angular frequency (default
@@ -1299,9 +1477,9 @@ class Netlist(NetlistMixin, NetfileMixin):
 
     """
 
-    def __init__(self, filename=None, context=None):
+    def __init__(self, filename=None, context=None, allow_anon=False):
 
-        super (Netlist, self).__init__(filename, context)
+        super (Netlist, self).__init__(filename, context, allow_anon=allow_anon)
         self._invalidate()
         self.kind = 'super'
 
@@ -1425,14 +1603,9 @@ class Netlist(NetlistMixin, NetfileMixin):
 
         return self.get_I(name).time()
 
-    def get_Vd(self, Np, Nm=None):
-        """Voltage drop between nodes"""
-
-        if isinstance(Nm, int):
-            Nm = '%s' % Nm
-        if isinstance(Np, int):
-            Np = '%s' % Np            
-
+    def _get_Vd(self, Np, Nm=None):
+        """This does not check nodes."""
+        
         result = Voltage()
         for sub in self.sub.values():
             Vd = sub.get_Vd(Np, Nm)
@@ -1440,6 +1613,12 @@ class Netlist(NetlistMixin, NetfileMixin):
         result = result.canonical()
         return result
 
+    def get_Vd(self, Np, Nm=None):
+        """Voltage drop between nodes"""
+
+        Np, Nm = self._check_nodes(Np, Nm)
+        return self._get_Vd(Np, Nm)
+
     def get_vd(self, Np, Nm=None):
         """Time-domain voltage drop between nodes"""
 
