@@ -18,6 +18,7 @@ from sympy.core.function import AppliedUndef
 import sympy as sym
 import re
 from .state import state
+from .simplify import simplify_dirac_delta, simplify_heaviside
 
 __all__ = ('symsymbol', 'sympify', 'simplify', 'symbol_delete')
 
@@ -217,6 +218,11 @@ def symsimplify(expr):
     # Handle Matrix types
     if hasattr(expr, 'applyfunc'):
         return expr.applyfunc(lambda x: symsimplify(x))
+
+    if expr.has(sym.DiracDelta):
+        expr = simplify_dirac_delta(expr)
+    if expr.has(sym.Heaviside):
+        expr = simplify_heaviside(expr)        
     
     try:
         if expr.is_Function and expr.func in (sym.Heaviside, sym.DiracDelta):
@@ -225,6 +231,7 @@ def symsimplify(expr):
         pass
 
     expr = sym.simplify(expr)
+
     return expr
 
 
@@ -306,11 +313,12 @@ def symbol_map(name):
 
 
 # The following are all SymPy symbols.
-ssym = symsymbol('s', real=False)
+ssym = symsymbol('s', complex=True)
 tsym = symsymbol('t', real=True)
 fsym = symsymbol('f', real=True)
 omegasym = symsymbol('omega', real=True)
 omega0sym = symsymbol('omega_0', real=True)
+tausym = symsymbol('tau', real=True)
 
 pi = sym.pi
 j = sym.I
