@@ -7,11 +7,11 @@ Copyright 2014--2020 Michael Hayes, UCECE
 from __future__ import division
 from .expr import Expr
 from .functions import exp
-from .sym import fsym, ssym, tsym, j, oo
+from .sym import fsym, ssym, tsym, j, oo, tausym
 from .acdc import ACChecker, is_dc, is_ac, is_causal
 from .laplace import laplace_transform
 from .fourier import fourier_transform
-import sympy as sym
+from sympy import Heaviside, limit, Integral
 
 __all__ = ('Ht', 'It', 'Vt', 'Yt', 'Zt')
 
@@ -26,15 +26,20 @@ class tExpr(Expr):
 
     def __init__(self, val, **assumptions):
 
+        check = assumptions.pop('check', True)        
         assumptions['real'] = True
         super(tExpr, self).__init__(val, **assumptions)
 
         self._fourier_conjugate_class = fExpr
         self._laplace_conjugate_class = sExpr
 
-        if self.expr.find(ssym) != set():
+        expr = self.expr        
+        if check and expr.find(ssym) != set() and not expr.has(Integral):
             raise ValueError(
-                't-domain expression %s cannot depend on s' % self.expr)
+                't-domain expression %s cannot depend on s' % expr)
+        if check and expr.find(fsym) != set() and not expr.has(Integral):
+            raise ValueError(
+                't-domain expression %s cannot depend on f' % expr)                            
 
     def infer_assumptions(self):
 
@@ -54,7 +59,7 @@ class tExpr(Expr):
         if is_causal(self, var):
             self.assumptions['causal'] = True
 
-    def laplace(self, **assumptions):
+    def laplace(self, evaluate=True, **assumptions):
         """Determine one-sided Laplace transform with 0- as the lower limit."""
 
         # The assumptions are required to help with the inverse Laplace
@@ -63,7 +68,7 @@ class tExpr(Expr):
 
         assumptions = self.merge_assumptions(**assumptions)
         
-        result = laplace_transform(self.expr, self.var, ssym)
+        result = laplace_transform(self.expr, self.var, ssym, evaluate=evaluate)
 
         if hasattr(self, '_laplace_conjugate_class'):
             result = self._laplace_conjugate_class(result, **assumptions)
@@ -76,12 +81,12 @@ class tExpr(Expr):
 
         return self.laplace(**assumptions)
     
-    def fourier(self, **assumptions):
+    def fourier(self, evaluate=True, **assumptions):
         """Attempt Fourier transform."""
 
         assumptions = self.merge_assumptions(**assumptions)
         
-        result = fourier_transform(self.expr, self.var, fsym)
+        result = fourier_transform(self.expr, self.var, fsym, evaluate=evaluate)
 
         if hasattr(self, '_fourier_conjugate_class'):
             result = self._fourier_conjugate_class(result, **assumptions)
@@ -136,7 +141,7 @@ class tExpr(Expr):
     def final_value(self):
         """Determine value at t = oo."""
 
-        return self.__class__(sym.limit(self.expr, self.var, oo))
+        return self.__class__(limit(self.expr, self.var, oo))
 
     def remove_condition(self):
         """Remove the piecewise condition from the expression.
@@ -158,9 +163,24 @@ class tExpr(Expr):
         expr = self.expr
         if self.is_conditional:
             expr = expr.args[0].args[0]            
-        expr = expr * sym.Heaviside(t)
+        expr = expr * Heaviside(t)
         return self.__class__(expr)        
 
+    def convolve(self, impulseresponse, commutate=False, **assumptions):
+        """Convolve self with impulse response."""
+
+        if not isinstance(impulseresponse, tExpr):
+            raise ValueError('Expecting tExpr for impulse response')
+
+        f1 = self.expr
+        f2 = impulseresponse.expr
+        if commutate:
+            f1, f2 = f2, f1
+        result = Integral(f1.subs(self.var, self.var - tausym) *
+                          f2.subs(self.var, tausym),
+                          (tausym, -oo, oo))
+        return self.__class__(result, **assumptions)
+
     
 class Yt(tExpr):
 
